@@ -2,7 +2,7 @@
  *
  * dos2unix '\n' converter 0.8.0
  *   based on Unix2Dos 0.9.0 by Peter Hanecak (made 19.2.1997)
- * Copyright 1997,.. by Peter Hanecak <hanecak@megaloman.sk>.
+ * Copyright 1997,.. by Peter Hanecak <hany@hany.sk>.
  * All rights reserved.
  *
  * Some portions by Rob Ginda <rginda@netscape.com> (07.2.2001)
@@ -33,10 +33,19 @@
 #include <string.h>
 #include <errno.h>
 #include <getopt.h>
-#include <sys/stat.h>
-#include <unistd.h>
+
 #include "config.h"
 
+#ifdef HAVE_SYS_STAT_H
+#include <sys/stat.h>
+#endif
+#ifdef HAVE_UNISTD_H
+#include <unistd.h>
+#endif
+#ifdef __MINGW32__
+#include <fcntl.h>
+#endif
+
 /* conversions */
 #define CT_AUTO     0
 #define CT_DOS2UNIX 1
@@ -135,7 +144,9 @@ int convert(char *fn, int convType) {
         in = stdin;
 
     /* construct temp file name */
+#ifndef _WIN32
     if ((getuid() == geteuid()) && (getgid() == getegid()))
+#endif
         if (!(tmpdir=getenv("TMPDIR")))
             tmpdir=getenv("TMP");
     if (!tmpdir)
@@ -148,7 +159,11 @@ int convert(char *fn, int convType) {
 
     /* open a temp file to store input */
     old_mode = umask(077);
+#ifndef _WIN32
     temp_fd = mkstemp(tempFn);
+#else
+    temp_fd = _open(_mktemp(tempFn), _O_WRONLY | _O_BINARY | _O_CREAT, _S_IRWXU | S_IREAD | S_IWRITE);
+#endif
     (void) umask(old_mode);
     if (temp_fd == -1)
         BAIL (-2, argv0);
